==> tdelibs-trinity_14.0.6.orig.tar.xz: tdelibs-trinity-14.0.6/tdeabc/vcard/include/VCardURIValue.h <==
/*
	libvcard - vCard parsing library for vCard version 3.0
	
	Copyright (C) 1999 Rik Hemsley rik@kde.org
	
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to
  deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
  AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#ifndef  URIVALUE_H
#define  URIVALUE_H

#include <VCardValue.h>

namespace VCARD
{

class KVCARD_EXPORT URIValue : public Value
{
#include "URIValue-generated.h"

	URIValue(const TQCString & scheme, const TQCString & schemeSpecificPart);
	
	TQCString scheme();
	TQCString schemeSpecificPart();
	
	void setScheme				(const TQCString &);
	void setSchemeSpecificPart	(const TQCString &);
	
	private:
	
		TQCString scheme_;
		TQCString schemeSpecificPart_;
};

}

#endif

==> tdelibs-trinity-14.1.5.tar.xz: tdelibs-trinity-14.1.5/tdeabc/vcard/include/VCardURIValue.h <==
/*
	libvcard - vCard parsing library for vCard version 3.0
	
	Copyright (C) 1999 Rik Hemsley rik@kde.org
	
  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to
  deal in the Software without restriction, including without limitation the
  rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
  sell copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
  AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
  ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

#ifndef  URIVALUE_H
#define  URIVALUE_H

#include <VCardValue.h>

namespace VCARD
{

class KVCARD_EXPORT URIValue : public Value
{
	public:
		URIValue();
		URIValue(const URIValue&);
		URIValue(const TQCString&);
		URIValue & operator = (URIValue&);
		URIValue & operator = (const TQCString&);
		bool operator ==(URIValue&);
		bool operator !=(URIValue& x) {return !(*this==x);}
		bool operator ==(const TQCString& s) {URIValue a(s);return(*this==a);} 
		bool operator != (const TQCString& s) {return !(*this == s);}

		virtual ~URIValue();
		void parse() {if(!parsed_) _parse();parsed_=true;assembled_=false;}

		void assemble() {if(assembled_) return;parse();_assemble();assembled_=true;}

		void _parse();
		void _assemble();
		const char * className() const { return "URIValue"; }

		URIValue(const TQCString & scheme, const TQCString & schemeSpecificPart);

		TQCString scheme();
		TQCString schemeSpecificPart();

		void setScheme				(const TQCString &);
		void setSchemeSpecificPart	(const TQCString &);
	
	private:
	
		TQCString scheme_;
		TQCString schemeSpecificPart_;
};

}

#endif
